
import java.util.List;
import java.util.ArrayList;
import java.util.Collections;

/** 
    Composite représente un noeud composé, ayant des enfants.
    Implémente les méthodes laissées vides dans Component.
**/
public abstract class Composite extends Component{
    
    protected List<Component> children = new ArrayList<>();
    
    public Composite(String name){
        super(name);
    }
    
    // Gestion des enfants
    public void addChild(Component child){
        children.add(child);
        child.setParent(this);
    }
    
    // opérations utilisant la structure composite
    public void print(){
        String spaces = String.join("", Collections.nCopies(getLevel(), "  "));
        System.out.println(spaces + getName() + " : " + getNombreLivres() + " livres, " + getNombrePages() + " pages");
        for(Component child : children){
            child.print();
        }
    }
    
    public int getNombreLivres(){
        int total = 0;
        for(Component child : children){
            total += child.getNombreLivres();
        }
        return total;
    }
    
    public int getNombrePages(){
        int total = 0;
        for(Component child : children){
            total += child.getNombrePages();
        }
        return total;
    }
    
}
